#
# spec file for package plasma5-phone-components
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# org.kde.phone.homescreen and org.kde.plasma.phone.taskpanel are internal,
# MeeGo.QOfono is optional and not packaged yet
%global __requires_exclude qmlimport\\((org\\.kde\\.phone\\.homescreen|org\\.kde\\.plasma\\.phone\\.taskpanel|MeeGo\\.QOfono).*

%define kf5_version 5.82.0

%bcond_without released
Name:           plasma5-phone-components
Version:        5.24.4
Release:        bp155.2.18
# Full Plasma 5 version (e.g. 5.9.3)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.9.3 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        Plasma Mobile
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/plasma-mobile-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-mobile-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  cmake(KF5Declarative) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5ModemManagerQt) >= %{kf5_version}
BuildRequires:  cmake(KF5NetworkManagerQt) >= %{kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{kf5_version}
BuildRequires:  cmake(KF5Plasma) >= %{kf5_version}
BuildRequires:  cmake(KF5PlasmaQuick) >= %{kf5_version}
BuildRequires:  cmake(KF5Service) >= %{kf5_version}
BuildRequires:  cmake(KF5Wayland) >= %{kf5_version}
BuildRequires:  cmake(KWinDBusInterface)
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.1.90
# TODO: Rename the package itself at some point
Provides:       plasma5-mobile = %{version}
# Forced on startup
Requires:       qqc2-breeze-style
# QML imports
Requires:       bluez-qt-imports
Requires:       kdeclarative-components
Requires:       kirigami2
Requires:       kwin5
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
Requires:       libqt5-qtwayland
Requires:       milou5
Requires:       plasma-nm5
Requires:       plasma5-nano
Requires:       plasma5-pa
Requires:       plasma5-workspace >= %{_plasma5_bugfix}
# TODO: import MeeGo.QOfono 0.2

%description
Plasma shell and components targeted for phones.

%prep
%autosetup -p1 -n plasma-mobile-%{version}

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
  %cmake_build

%install
  %kf5_makeinstall -C build

  # Wut?
  sed -i '#touch /tmp/simplelogin_starting#d' %{buildroot}%{_kf5_bindir}/kwinwrapper

  %fdupes %{buildroot}

%files
%license LICENSES/*
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%dir %{_kf5_qmldir}/org/kde/plasma/
%{_kf5_qmldir}/org/kde/plasma/mm/
%dir %{_kf5_qmldir}/org/kde/plasma/private/
%dir %{_kf5_qmldir}/org/kde/plasma/quicksetting/
%{_kf5_qmldir}/org/kde/plasma/private/mobilehomescreencomponents/
%{_kf5_qmldir}/org/kde/plasma/private/mobileshell/
%{_kf5_qmldir}/org/kde/plasma/quicksetting/nightcolor/
%{_kf5_bindir}/kwinwrapper
%dir %{_datadir}/wayland-sessions/
%{_datadir}/wayland-sessions/plasma-mobile.desktop
%dir %{_kf5_plasmadir}/look-and-feel/
%{_kf5_plasmadir}/look-and-feel/org.kde.plasma.phone/
%dir %{_kf5_plasmadir}/shells
%{_kf5_plasmadir}/shells/org.kde.plasma.phoneshell/
%dir %{_kf5_plasmadir}/plasmoids/
%{_kf5_plasmadir}/plasmoids/org.kde.phone.panel/
%{_kf5_plasmadir}/plasmoids/org.kde.phone.homescreen/
%{_kf5_plasmadir}/plasmoids/org.kde.phone.taskpanel/
%{_kf5_notifydir}/plasma_phone_components.notifyrc
%dir %{_kf5_plasmadir}/quicksettings/
%{_kf5_plasmadir}/quicksettings/org.kde.plasma.airplanemode/
%{_kf5_plasmadir}/quicksettings/org.kde.plasma.nightcolor/
%dir %{_kf5_plugindir}/plasma/
%dir %{_kf5_plugindir}/plasma/applets/
%{_kf5_plugindir}/plasma/applets/plasma_applet_phonepanel.so
%{_kf5_plugindir}/plasma/applets/plasma_containment_phone_homescreen.so
%{_kf5_plugindir}/plasma/applets/plasma_containment_phone_taskpanel.so
%{_kf5_appstreamdir}/org.kde.plasma.phone.appdata.xml
%{_kf5_appstreamdir}/org.kde.plasma.phoneshell.appdata.xml
%{_kf5_servicesdir}/plasma-applet-org.kde.phone.homescreen.desktop
%{_kf5_servicesdir}/plasma-applet-org.kde.phone.panel.desktop
%{_kf5_servicesdir}/plasma-applet-org.kde.phone.taskpanel.desktop
%{_kf5_servicesdir}/plasma-applet-org.kde.plasma.airplanemode.desktop
%{_kf5_servicesdir}/plasma-applet-org.kde.plasma.nightcolor.desktop
%{_kf5_servicesdir}/plasma-applet-org.kde.plasma.phone.desktop
%{_kf5_servicesdir}/plasma-applet-org.kde.plasma.phoneshell.desktop

%changelog
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- Changes since 5.24.3:
  * mmplugin: set all connections to not autoconnect on setMobileDataEnabled(false) (#182)
* Wed Mar  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Remove applets/activities, applets/krunner and the lang
  subpackage (since those applets where the only ones using it)
  as they were removed by upstream.
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- Changes since 5.24.1:
  * actiondrawer: Darken landscape drawer background to be easier to read
  * quicksettings: Ensure mobile data quick setting says not available if not available
  * Ensure we have a default wallpaper
  * homescreen: Fix app drawer not interactable in empty space
  * taskpanel: Fix close action
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- Changes since 5.24.0:
  * mmplugin: Use NM autoconnect instead of wwan
  * ci: Add networkmanager-qt
  * quicksettings: Make mobile data quick setting use NM API directly
  * taskswitcher: Ensure window is in maximized state when activating
  * taskswitcher: Remove global variable calls
  * mmplugin: Fix SIM being reported as locked when no sim is inserted
  * applets/activities & applets/krunner: Remove from repo
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * applets/activities & applets/krunner: Remove from repo
  * [shell/updates] Ensure upgrade process has new panel height
  * Fix meta shortcut being removed regression
  * homescreen: Don't disable flick tracking unnecessarily
  * homescreen: Only close app drawer after startup feedback is fullscreen
  * lockscreen: Use smaller up icon
  * widgets/krunner: Fix keyboard focus being invoked on shell startup
  * homescreen: Close app drawer when app is launched
  * homescreen: Reset app drawer position when opened
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Too many changes to list here
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- Changes since 5.23.4:
  * panel: Fix SIM Locked being shown when no sim is inserted
* Fri Dec 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix package build with plasma-framework 5.89.0.
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- Changes since 5.23.3:
  * homescreen: Fix silly type name error
  * Fix broken reset homescreen position signal, and minor refactor
  * Rework app drawer layout and open/close behaviour logic
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- Changes since 5.23.0:
  * panel: Fix quicksetting delegate width not getting enforced on label
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * Fix path->URL conversion error, detected by -DQT_NO_URL_CAST_FROM_STRING
  * Do not show "Sim Locked" when there's no SIM card
  * Revert "phonepanel: Keep the Quick Settings buttons the same size"
  * lockscreen: Fix text input not working because of predictive text
  * phonepanel: Keep the Quick Settings buttons the same size
  * Add airplane mode in quicksettings
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Too many changes to list here
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- Changes since 5.22.3:
  * Make sure the closed signal is emitted upon close
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%files section. plasma-framework >= 5.84 doesn't install
  desktop files in %%_kf5_servicesdir anymore.
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- Changes since 5.22.0:
  * lockscreen: handle all cases for lockscreen keyboard focus
  * lockscreen: explicitly tell keyboard to open rather than relying on focus
  * panel: remove unnecessary color changes for header panel when quicksettings open
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * lockscreen: don't make password bar go off the screen if keyboard reports height larger than screen height
  * Don't reopen keyboard after krunner dialog closes
  * Make pin screen follow color scheme
  * lockscreen: do not show percentage for signal strength
  * indicators: clean-up useless debug
  * indicators: do not needlessly scan again
  * Use alternateBackgroundColor for OpenDrawerButton
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Too many changes to list here
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- Changes since 5.21.3:
  * lockscreen: Accept pin on numpad enter
  * Fix typo
* Wed Mar 24 2021 Andrés B.S. <andresbs@opensuse.org>
- Add missing Wayland runtime dependency
  * QT_QPA_PLATFORM is forced from kwinwrapper
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- Changes since 5.21.2:
  * Fix panel clock from not respecting 12/24 hour settings
  * Avoid potential double dbus start
  * remove code pushed by mistake
  * apporder reflects favorites
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- Changes since 5.21.1:
  * Fix the SignalStrength indicator on lockscreen
  * Use Header colors for top panel
  * shell: keep panelsfix.js in sync with layout.js
  * fix horizontal scrolling of applets
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- Changes since 5.21.0:
  * Tweak app drawer behavior
  * enable the drag handler only when the containment has focus
  * Close sliding panel as soon as it's off the screen for no delay
  * Cancel sliding panel animations on touch so it's more responsive
  * respect max favorite count when dropping
* Mon Feb 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * remove use of dead proeprties
  * More familiar behavior for the App Drawer
  * Use loop instead of recursion
  * Fix logic error in f19f629b4ba85
  * add back panels if they disappeared
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Too many changes to list here
* Fri Jan 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Fri Dec 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Initial package
